@@ -1,9 +1,12 @@
 # Copyright 2017 Palantir Technologies, Inc.
+import os
 from pyls import lsp, uris
 from pyls.workspace import Document
 from pyls.plugins import pydocstyle_lint
 
-DOC_URI = uris.from_fs_path(__file__)
+DOC_URI = uris.from_fs_path(os.path.join(os.path.dirname(__file__), "pydocstyle.py"))
+TEST_DOC_URI = uris.from_fs_path(__file__)
+
 DOC = """import sys
 
 def hello():
@@ -13,9 +16,9 @@ import json
 """
 
 
-def test_pydocstyle():
-    doc = Document(DOC_URI, DOC)
-    diags = pydocstyle_lint.pyls_lint(doc)
+def test_pydocstyle(config, workspace):
+    doc = Document(DOC_URI, workspace, DOC)
+    diags = pydocstyle_lint.pyls_lint(config, doc)
 
     assert all([d['source'] == 'pydocstyle' for d in diags])
 
@@ -32,15 +35,22 @@ def test_pydocstyle():
     }
 
 
-def test_pydocstyle_empty_source():
-    doc = Document(DOC_URI, "")
-    diags = pydocstyle_lint.pyls_lint(doc)
+def test_pydocstyle_test_document(config, workspace):
+    # The default --match argument excludes test_* documents.
+    doc = Document(TEST_DOC_URI, workspace, "")
+    diags = pydocstyle_lint.pyls_lint(config, doc)
+    assert not diags
+
+
+def test_pydocstyle_empty_source(config, workspace):
+    doc = Document(DOC_URI, workspace, "")
+    diags = pydocstyle_lint.pyls_lint(config, doc)
     assert diags[0]['message'] == 'D100: Missing docstring in public module'
     assert len(diags) == 1
 
 
-def test_pydocstyle_invalid_source():
-    doc = Document(DOC_URI, "bad syntax")
-    diags = pydocstyle_lint.pyls_lint(doc)
+def test_pydocstyle_invalid_source(config, workspace):
+    doc = Document(DOC_URI, workspace, "bad syntax")
+    diags = pydocstyle_lint.pyls_lint(config, doc)
     # We're unable to parse the file, so can't get any pydocstyle diagnostics
     assert not diags
