@@ -1,26 +1,13 @@
 # Copyright 2017 Palantir Technologies, Inc.
 import time
-import sys
 
 import mock
+from flaky import flaky
 
 from pyls import _utils
 
 
-class MockWorkspace(object):
-    """Mock workspace used by tests that use jedi environment."""
-
-    def __init__(self):
-        """Mock workspace used by tests that use jedi environment."""
-        self._environments = {}
-
-        # This is to avoid pyling tests of the variable not being used
-        sys.stdout.write(str(self._environments))
-
-        # This necessary for the new Jedi 0.17+ API.
-        self.root_path = ''
-
-
+@flaky
 def test_debounce():
     interval = 0.1
     obj = mock.Mock()
@@ -44,6 +31,7 @@ def test_debounce():
     assert len(obj.mock_calls) == 2
 
 
+@flaky
 def test_debounce_keyed_by():
     interval = 0.1
     obj = mock.Mock()
